﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Services;
using System.Web.Script.Services;
using System.Data;
using System.Web.Script.Serialization;


/// <summary>
/// WebService
/// </summary>
[WebService(Namespace = "http://tempuri.org/")]
[WebServiceBinding(ConformsTo = WsiProfiles.BasicProfile1_1)]
[System.Web.Script.Services.ScriptService]
public class WebService : System.Web.Services.WebService {

    GridViewModel model = new GridViewModel();

    public WebService () {

    }

    [WebMethod]
    public string HelloWorld() {
        return "Hello World";
    }

    [WebMethod]
    [ScriptMethod(UseHttpGet = true, ResponseFormat = ResponseFormat.Json)]
    public void GetTree()
    {
        List<rowdata> data = new List<rowdata>();

        for (int index = 1; index <= 3; index++)
        {
            rowdata row = new rowdata();
            row.ID = index;
            row.Name = "Name_" + index.ToString();
            row.Items = new List<rowdata>();
            data.Add(row);
        }

        JavaScriptSerializer js = new JavaScriptSerializer();
        Context.Response.Clear();
        Context.Response.ContentType = "application/json";
        Context.Response.Write(js.Serialize(data));
    }

    [WebMethod]
    [ScriptMethod(UseHttpGet = true, ResponseFormat = ResponseFormat.Json)]
    public string GetFirstLevel()
    {
        var data = model.Summaries;
        return new JavaScriptSerializer().Serialize(data);
    }

    [WebMethod]
    [ScriptMethod(UseHttpGet = true, ResponseFormat = ResponseFormat.Json)]
    public string GetSecondLevel()
    {
        string path = this.Context.Request.QueryString["path"].ToString();
        string summaryID = path.Split(':')[1];

        var data = model.Stores.Where(p => p.SummaryID == summaryID);

        JavaScriptSerializer js = new JavaScriptSerializer();
        return js.Serialize(data);
    }

    [WebMethod]
    [ScriptMethod(UseHttpGet = true, ResponseFormat = ResponseFormat.Json)]
    public string GetThirdLevel()
    {
        string path = this.Context.Request.QueryString["path"].ToString();
        string store = path.Split('/')[1];
        int storeID = Convert.ToInt32(store.Split(':')[1]);

        var data = model.Terminals.Where(p => p.StoreID == storeID);

        JavaScriptSerializer js = new JavaScriptSerializer();
        return js.Serialize(data);
    }

    public class rowdata
    {
        public int ID;
        public string Name;
        public List<rowdata> Items;
    }


    public class GridViewModel
    {
        private List<Summary> summaries;
        private List<Store> stores;
        private List<Terminal> terminals;

        #region Public Properties

        public IQueryable<Summary> Summaries
        {
            get
            {
                if (summaries == null)
                    summaries = CreateSummaries();

                return summaries.AsQueryable<Summary>();
            }
        }

        public IQueryable<Store> Stores
        {
            get
            {
                if (stores == null)
                    stores = CreateStores();

                return stores.AsQueryable<Store>();
            }
        }

        public IQueryable<Terminal> Terminals
        {
            get
            {
                if (terminals == null)
                    terminals = CreateTerminals();

                return terminals.AsQueryable<Terminal>();
            }
        }

        #endregion

        #region private methods

        private List<Summary> CreateSummaries()
        {
            return new List<Summary>
            {
                new Summary 
                {
                    SummaryID = "020", 
                    SummaryName = "2014/08/01", 
                    StoreCount = 5,
                    InProcessCount = 0,
                    Deadline1 = 20,
                    Deadline2 = 0,
                    Deadline3 = 0,
                    Deadline4 = 0,
                    Deadline5 = 0,
                    Deadline6 = 0,
                    Deadline7 = 0,
                    Deadline8 = 0,
                    Deadline9 = 0,
                    Deadline10 = 0,
                    Description = "test"
                }

            };
        }


        private List<Store> CreateStores()
        {
            return new List<Store>
            {
                new Store 
                {
                    SummaryID = "020", 
                    StoreID = 1, 
                    StoreName = "静岡田町店", 
                    CeName = "名前1", 
                    ExpectedDate = DateTime.Today, 
                    Deadline1 = DateTime.Today,
                    Description = "注意書きテスト注意書きテスト"
                },

                new Store 
                {
                    SummaryID = "020", 
                    StoreID = 2, 
                    StoreName = "静岡駅アスティ店", 
                    CeName = "名前2", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                },
                
                new Store
                {
                    SummaryID = "020", 
                    StoreID = 3,
                    StoreName = "静岡呉服町店",
                    CeName = "名前3", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                },

                new Store
                {
                    SummaryID = "020", 
                    StoreID = 4,
                    StoreName = "静岡新富町店",
                    CeName = "名前4", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                },

                new Store
                {
                    SummaryID = "020", 
                    StoreID = 5,
                    StoreName = "薬局 新静岡セノバ店",
                    CeName = "名前5", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                },

                new Store
                {
                    SummaryID = "020", 
                    StoreID = 6,
                    StoreName = "渋谷店",
                    CeName = "名前6", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                },

                new Store
                {
                    SummaryID = "020", 
                    StoreID = 7,
                    StoreName = "池袋店",
                    CeName = "名前7", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                },

                new Store
                {
                    SummaryID = "020", 
                    StoreID = 8,
                    StoreName = "新宿店",
                    CeName = "名前8", 
                    ExpectedDate = DateTime.Today, 
                    Description = "注意書きテスト注意書きテスト"
                }
            };
        }

        private static List<Terminal> CreateTerminals()
        {
            return new List<Terminal>
            {
                new Terminal
                {
                    TerminalID = 1,
                    TerminalName = "Chai",
                    StoreID = 1,
                    QuantityPerUnit = "10 boxes x 20 bags",
                    UnitPrice = 18.0000m,
                    UnitsInStock = 39,
                    UnitsOnOrder = 0,
                    ReorderLevel = 10,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 2,
                    TerminalName = "Chang",
                    StoreID = 1,
                    QuantityPerUnit = "24 - 12 oz bottles",
                    UnitPrice = 19.0000m,
                    UnitsInStock = 17,
                    UnitsOnOrder = 40,
                    ReorderLevel = 25,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 24,
                    TerminalName = "Guaraná Fantástica",
                    StoreID = 1,
                    QuantityPerUnit = "12 - 355 ml cans",
                    UnitPrice = 4.5000m,
                    UnitsInStock = 20,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = true
                },

                new Terminal
                {
                    TerminalID = 77,
                    TerminalName = "Original Frankfurter grüne Soße",
                    StoreID = 2,
                    QuantityPerUnit = "12 boxes",
                    UnitPrice = 13.0000m,
                    UnitsInStock = 32,
                    UnitsOnOrder = 0,
                    ReorderLevel = 15,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 61,
                    TerminalName = "Sirop d'érable",
                    StoreID = 2,
                    QuantityPerUnit = "24 - 500 ml bottles",
                    UnitPrice = 28.5000m,
                    UnitsInStock = 113,
                    UnitsOnOrder = 0,
                    ReorderLevel = 25,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 63,
                    TerminalName = "Vegie-spread",
                    StoreID = 2,
                    QuantityPerUnit = "15 - 625 g jars",
                    UnitPrice = 43.9000m,
                    UnitsInStock = 24,
                    UnitsOnOrder = 0,
                    ReorderLevel = 5,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 16,
                    TerminalName = "Pavlova",
                    StoreID = 3,
                    QuantityPerUnit = "32 - 500 g boxes",
                    UnitPrice = 17.4500m,
                    UnitsInStock = 29,
                    UnitsOnOrder = 0,
                    ReorderLevel = 10,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 19,
                    TerminalName = "Teatime Chocolate Biscuits",
                    StoreID = 3,
                    QuantityPerUnit = "10 boxes x 12 pieces",
                    UnitPrice = 9.2000m,
                    UnitsInStock = 25,
                    UnitsOnOrder = 0,
                    ReorderLevel = 5,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 20,
                    TerminalName = "Sir Rodney's Marmalade",
                    StoreID = 3,
                    QuantityPerUnit = "30 gift boxes",
                    UnitPrice = 81.0000m,
                    UnitsInStock = 40,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 69,
                    TerminalName = "Gudbrandsdalsost",
                    StoreID = 4,
                    QuantityPerUnit = "10 kg pkg.",
                    UnitPrice = 36.0000m,
                    UnitsInStock = 26,
                    UnitsOnOrder = 0,
                    ReorderLevel = 15,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 71,
                    TerminalName = "Flotemysost",
                    StoreID = 4,
                    QuantityPerUnit = "10 - 500 g pkgs.",
                    UnitPrice = 21.5000m,
                    UnitsInStock = 26,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 72,
                    TerminalName = "Mozzarella di Giovanni",
                    StoreID = 4,
                    QuantityPerUnit = "24 - 200 g pkgs.",
                    UnitPrice = 34.8000m,
                    UnitsInStock = 14,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = false
                },
                new Terminal
                {
                    TerminalID = 22,
                    TerminalName = "Gustaf's Knäckebröd",
                    StoreID = 5,
                    QuantityPerUnit = "24 - 500 g pkgs.",
                    UnitPrice = 21.0000m,
                    UnitsInStock = 104,
                    UnitsOnOrder = 0,
                    ReorderLevel = 25,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 23,
                    TerminalName = "Tunnbröd",
                    StoreID = 5,
                    QuantityPerUnit = "12 - 250 g pkgs.",
                    UnitPrice = 9.0000m,
                    UnitsInStock = 61,
                    UnitsOnOrder = 0,
                    ReorderLevel = 25,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 53,
                    TerminalName = "Perth Pasties",
                    StoreID = 6,
                    QuantityPerUnit = "48 pieces",
                    UnitPrice = 32.8000m,
                    UnitsInStock = 0,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = true
                },

                new Terminal
                {
                    TerminalID = 54,
                    TerminalName = "Tourtière",
                    StoreID = 6,
                    QuantityPerUnit = "16 pies",
                    UnitPrice = 7.4500m,
                    UnitsInStock = 21,
                    UnitsOnOrder = 0,
                    ReorderLevel = 10,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 55,
                    TerminalName = "Pâté chinois",
                    StoreID = 6,
                    QuantityPerUnit = "24 boxes x 2 pies",
                    UnitPrice = 24.0000m,
                    UnitsInStock = 115,
                    UnitsOnOrder = 0,
                    ReorderLevel = 20,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 28,
                    TerminalName = "Rössle Sauerkraut",
                    StoreID = 7,
                    QuantityPerUnit = "25 - 825 g cans",
                    UnitPrice = 45.6000m,
                    UnitsInStock = 26,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = true
                },

                new Terminal
                {
                    TerminalID = 7,
                    TerminalName = "Uncle Bob's Organic Dried Pears",
                    StoreID = 7,
                    QuantityPerUnit = "12 - 1 lb pkgs.",
                    UnitPrice = 30.0000m,
                    UnitsInStock = 15,
                    UnitsOnOrder = 0,
                    ReorderLevel = 10,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 14,
                    TerminalName = "Tofu",
                    StoreID = 7,
                    QuantityPerUnit = "40 - 100 g pkgs.",
                    UnitPrice = 23.2500m,
                    UnitsInStock = 35,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 45,
                    TerminalName = "Rogede sild",
                    StoreID = 8,
                    QuantityPerUnit = "1k pkg.",
                    UnitPrice = 9.5000m,
                    UnitsInStock = 5,
                    UnitsOnOrder = 70,
                    ReorderLevel = 15,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 46,
                    TerminalName = "Spegesild",
                    StoreID = 8,
                    QuantityPerUnit = "4 - 450 g glasses",
                    UnitPrice = 12.0000m,
                    UnitsInStock = 95,
                    UnitsOnOrder = 0,
                    ReorderLevel = 0,
                    Discontinued = false
                },

                new Terminal
                {
                    TerminalID = 58,
                    TerminalName = "Escargots de Bourgogne",
                    StoreID = 8,
                    QuantityPerUnit = "24 pieces",
                    UnitPrice = 13.2500m,
                    UnitsInStock = 62,
                    UnitsOnOrder = 0,
                    ReorderLevel = 20,
                    Discontinued = false
                }
            };
        }

        private List<Store> CreateStoresAndTerminals()
        {
            List<Store> retVal = CreateStores();

            List<Terminal> tempTerminals = CreateTerminals();

            Store parentStore = null;

            foreach (Terminal p in tempTerminals)
            {
                if (parentStore == null || parentStore.StoreID != p.StoreID)
                {
                    parentStore = retVal.First<Store>(store => store.StoreID == p.StoreID);
                }

                //parentStore.AddTerminal(p);
            }

            return retVal;
        }

        #endregion
    }

    public class Summary
    {
        #region private fields

        private string summaryID;
        private string summaryName;
        private int storeCount;
        private int inProcessCount;

        private int deadline1;
        private int deadline2;
        private int deadline3;
        private int deadline4;
        private int deadline5;
        private int deadline6;
        private int deadline7;
        private int deadline8;
        private int deadline9;
        private int deadline10;

        private string description;
        //private List<Terminal> terminals;

        #endregion

        #region public summaries

        public string SummaryID
        {
            get
            {
                return this.summaryID;
            }
            set
            {
                if (this.summaryID != value)
                {
                    this.summaryID = value;
                }
            }
        }

        public string SummaryName
        {
            get
            {
                return this.summaryName;
            }
            set
            {
                if (this.summaryName != value)
                {
                    this.summaryName = value;
                }
            }
        }

        public int StoreCount
        {
            get
            {
                return this.storeCount;
            }
            set
            {
                if (this.storeCount != value)
                {
                    this.storeCount = value;
                }
            }
        }

        public int InProcessCount
        {
            get
            {
                return this.inProcessCount;
            }
            set
            {
                if (this.inProcessCount != value)
                {
                    this.inProcessCount = value;
                }
            }
        }

        public int Deadline1
        {
            get
            {
                return this.deadline1;
            }
            set
            {
                if (this.deadline1 != value)
                {
                    this.deadline1 = value;
                }
            }
        }
        public int Deadline2
        {
            get
            {
                return this.deadline2;
            }
            set
            {
                if (this.deadline2 != value)
                {
                    this.deadline2 = value;
                }
            }
        }
        public int Deadline3
        {
            get
            {
                return this.deadline3;
            }
            set
            {
                if (this.deadline3 != value)
                {
                    this.deadline3 = value;
                }
            }
        }
        public int Deadline4
        {
            get
            {
                return this.deadline4;
            }
            set
            {
                if (this.deadline4 != value)
                {
                    this.deadline4 = value;
                }
            }
        }
        public int Deadline5
        {
            get
            {
                return this.deadline5;
            }
            set
            {
                if (this.deadline5 != value)
                {
                    this.deadline5 = value;
                }
            }
        }
        public int Deadline6
        {
            get
            {
                return this.deadline6;
            }
            set
            {
                if (this.deadline6 != value)
                {
                    this.deadline6 = value;
                }
            }
        }
        public int Deadline7
        {
            get
            {
                return this.deadline7;
            }
            set
            {
                if (this.deadline7 != value)
                {
                    this.deadline7 = value;
                }
            }
        }
        public int Deadline8
        {
            get
            {
                return this.deadline8;
            }
            set
            {
                if (this.deadline8 != value)
                {
                    this.deadline8 = value;
                }
            }
        }
        public int Deadline9
        {
            get
            {
                return this.deadline9;
            }
            set
            {
                if (this.deadline9 != value)
                {
                    this.deadline9 = value;
                }
            }
        }
        public int Deadline10
        {
            get
            {
                return this.deadline10;
            }
            set
            {
                if (this.deadline10 != value)
                {
                    this.deadline10 = value;
                }
            }
        }

        public string Description
        {
            get
            {
                return this.description;
            }
            set
            {
                if (this.description != value)
                {
                    this.description = value;
                }
            }
        }

        #endregion

        #region public methods

        //public void AddTerminal(Terminal newTerminal)
        //{
        //    terminals.Add(newTerminal);
        //}

        #endregion
    }

    public class Store
    {
        #region private fields

        private string summaryID;
        private int storeID;
        private string storeName;
        private string ceName;
        private DateTime? expectedName;

        private DateTime? deadline1;
        private DateTime? deadline2;
        private DateTime? deadline3;
        private DateTime? deadline4;
        private DateTime? deadline5;
        private DateTime? deadline6;
        private DateTime? deadline7;
        private DateTime? deadline8;
        private DateTime? deadline9;
        private DateTime? deadline10;

        private string description;
        //private List<Terminal> terminals;

        #endregion

        #region public properties

        //public IQueryable<Terminal> Terminals
        //{
        //    get
        //    {
        //        if (terminals == null)
        //        {
        //            terminals = new List<Terminal>();
        //        }

        //        return this.terminals.AsQueryable<Terminal>();
        //    }
        //}


        public string SummaryID
        {
            get
            {
                return this.summaryID;
            }
            set
            {
                if (this.summaryID != value)
                {
                    this.summaryID = value;
                }
            }
        }

        public int StoreID
        {
            get
            {
                return this.storeID;
            }
            set
            {
                if (this.storeID != value)
                {
                    this.storeID = value;
                }
            }
        }

        public string StoreName
        {
            get
            {
                return this.storeName;
            }
            set
            {
                if (this.storeName != value)
                {
                    this.storeName = value;
                }
            }
        }

        public string CeName
        {
            get
            {
                return this.ceName;
            }
            set
            {
                if (this.ceName != value)
                {
                    this.ceName = value;
                }
            }
        }

        public DateTime? ExpectedDate
        {
            get
            {
                return this.expectedName;
            }
            set
            {
                if (this.expectedName != value)
                {
                    this.expectedName = value;
                }
            }
        }

        public DateTime? Deadline1
        {
            get
            {
                return this.deadline1;
            }
            set
            {
                if (this.deadline1 != value)
                {
                    this.deadline1 = value;
                }
            }
        }
        public DateTime? Deadline2
        {
            get
            {
                return this.deadline2;
            }
            set
            {
                if (this.deadline2 != value)
                {
                    this.deadline2 = value;
                }
            }
        }
        public DateTime? Deadline3
        {
            get
            {
                return this.deadline3;
            }
            set
            {
                if (this.deadline3 != value)
                {
                    this.deadline3 = value;
                }
            }
        }
        public DateTime? Deadline4
        {
            get
            {
                return this.deadline4;
            }
            set
            {
                if (this.deadline4 != value)
                {
                    this.deadline4 = value;
                }
            }
        }
        public DateTime? Deadline5
        {
            get
            {
                return this.deadline5;
            }
            set
            {
                if (this.deadline5 != value)
                {
                    this.deadline5 = value;
                }
            }
        }
        public DateTime? Deadline6
        {
            get
            {
                return this.deadline6;
            }
            set
            {
                if (this.deadline6 != value)
                {
                    this.deadline6 = value;
                }
            }
        }
        public DateTime? Deadline7
        {
            get
            {
                return this.deadline7;
            }
            set
            {
                if (this.deadline7 != value)
                {
                    this.deadline7 = value;
                }
            }
        }
        public DateTime? Deadline8
        {
            get
            {
                return this.deadline8;
            }
            set
            {
                if (this.deadline8 != value)
                {
                    this.deadline8 = value;
                }
            }
        }
        public DateTime? Deadline9
        {
            get
            {
                return this.deadline9;
            }
            set
            {
                if (this.deadline9 != value)
                {
                    this.deadline9 = value;
                }
            }
        }
        public DateTime? Deadline10
        {
            get
            {
                return this.deadline10;
            }
            set
            {
                if (this.deadline10 != value)
                {
                    this.deadline10 = value;
                }
            }
        }

        public string Description
        {
            get
            {
                return this.description;
            }
            set
            {
                if (this.description != value)
                {
                    this.description = value;
                }
            }
        }

        #endregion

        #region public methods

        //public void AddTerminal(Terminal newTerminal)
        //{
        //    terminals.Add(newTerminal);
        //}

        #endregion
    }

    public class Terminal
    {
        #region private members

        private int terminalID;
        private string terminalName;
        private int storeID;
        private string quantityPerUnit;
        private decimal unitPrice;
        private int unitsInStock;
        private int unitsOnOrder;
        private int reorderLevel;
        private bool discontinued;

        #endregion

        #region public properties

        public int TerminalID
        {
            get
            {
                return this.terminalID;
            }
            set
            {
                if (this.terminalID != value)
                {
                    this.terminalID = value;
                }
            }
        }

        public string TerminalName
        {
            get
            {
                return this.terminalName;
            }
            set
            {
                if (this.terminalName != value)
                {
                    this.terminalName = value;
                }
            }
        }

        public int StoreID
        {
            get
            {
                return this.storeID;
            }
            set
            {
                if (this.storeID != value)
                {
                    this.storeID = value;
                }
            }
        }

        public string QuantityPerUnit
        {
            get
            {
                return this.quantityPerUnit;
            }
            set
            {
                if (this.quantityPerUnit != value)
                {
                    this.quantityPerUnit = value;
                }
            }
        }

        public decimal UnitPrice
        {
            get
            {
                return this.unitPrice;
            }
            set
            {
                if (value < 0)
                    throw new Exception("Negative numbers are not allowed.");

                this.unitPrice = value;
            }
        }

        public int UnitsInStock
        {
            get
            {
                return this.unitsInStock;
            }
            set
            {
                if (value < 0)
                    throw new Exception("Negative numbers are not allowed.");

                this.unitsInStock = value;
            }
        }

        public int UnitsOnOrder
        {
            get
            {
                return this.unitsOnOrder;
            }
            set
            {
                if (this.unitsOnOrder != value)
                {
                    this.unitsOnOrder = value;
                }
            }
        }

        public int ReorderLevel
        {
            get
            {
                return this.reorderLevel;
            }
            set
            {
                if (this.reorderLevel != value)
                {
                    this.reorderLevel = value;
                }
            }
        }

        public bool Discontinued
        {
            get
            {
                return this.discontinued;
            }
            set
            {
                if (this.discontinued != value)
                {
                    this.discontinued = value;
                }
            }
        }

        #endregion
    }

}
